.. _release_notes:

=============
Release notes
=============

This is the list of changes to Gammapy between each release. For full details,
see the `commit logs <https://github.com/gammapy/gammapy/commits/main>`_.
A complete list of Gammapy contributors is at https://gammapy.org/team.html

Version 1.1
-----------

.. toctree::
   :maxdepth: 2

   v1.1

Version 1.0.1
-------------

.. toctree::
   :maxdepth: 2

   v1.0.1

Version 1.0
-----------

.. toctree::
   :maxdepth: 2

   v1.0

Version 0.20.1
--------------

.. toctree::
   :maxdepth: 2

   v0.20.1

Version 0.20
------------

.. toctree::
   :maxdepth: 2

   v0.20


Version 0.19
------------

.. toctree::
   :maxdepth: 2

   v0.19

Version 0.18
------------

.. toctree::
   :maxdepth: 2

   v0.18.2
   v0.18.1
   v0.18


Version 0.17
------------

.. toctree::
   :maxdepth: 2

   v0.17

Version 0.16
------------

.. toctree::
   :maxdepth: 2

   v0.16

Version 0.15
------------

.. toctree::
   :maxdepth: 2

   v0.15

Version 0.14
------------

.. toctree::
   :maxdepth: 2

   v0.14

Version 0.13
------------

.. toctree::
   :maxdepth: 2

   v0.13

Version 0.12
------------

.. toctree::
   :maxdepth: 2

   v0.12

Version 0.11
------------

.. toctree::
   :maxdepth: 2

   v0.11

Version 0.10
------------

.. toctree::
   :maxdepth: 2

   v0.10

Version 0.9
-----------

.. toctree::
   :maxdepth: 2

   v0.9

Version 0.8
-----------

.. toctree::
   :maxdepth: 2

   v0.8

Version 0.7
-----------

.. toctree::
   :maxdepth: 2

   v0.7

Version 0.6
-----------

.. toctree::
   :maxdepth: 2

   v0.6

Version 0.5
-----------

.. toctree::
   :maxdepth: 2

   v0.5

Version 0.4
-----------

.. toctree::
   :maxdepth: 2

   v0.4

Version 0.3
-----------

.. toctree::
   :maxdepth: 2

   v0.3

Version 0.2
-----------

.. toctree::
   :maxdepth: 2

   v0.2

Version 0.1
-----------

.. toctree::
   :maxdepth: 2

   v0.1
